@@ -1,6 +1,6 @@
 package Smart::Comments;
 
-use version; $VERSION = qv('1.0.3');
+our $VERSION = '1.000005';
 
 use warnings;
 use strict;
@@ -427,10 +427,12 @@ sub _Dump {
     my %args = @_;
     my ($pref, $varref, $nonl) = @args{qw(pref var nonl)};
 
-    # Handle timestamps...
+    # Handle timestamps and spacestamps...
     my (undef, $file, $line) = caller;
     $pref =~ s/<(?:now|time|when)>/scalar localtime()/ge;
     $pref =~ s/<(?:here|place|where)>/"$file", line $line/g;
+    $pref =~ s/<(?:file)>/$file/g;
+    $pref =~ s/<(?:line)>/$line/g;
 
     # Add a newline?
     my @caller = caller;
@@ -491,7 +493,7 @@ Smart::Comments - Comments that do more than just sit there
 
 =head1 VERSION
 
-This document describes Smart::Comments version 1.0.3
+This document describes Smart::Comments version 1.000005
 
 
 =head1 SYNOPSIS
@@ -678,8 +680,8 @@ would produce something like:
 
     ### [Fri Nov 18 15:11:15 EST 2005] Acquiring data...
 
-There are also "spacestamps": C<< <here> >> (or C<< <line> >> or C<<
-<loc> >> or C<< <place> >> or C<< <where> >>):
+There are also "spacestamps": C<< <here> >>
+(or C<< <loc> >> or C<< <place> >> or C<< <where> >>):
 
     ### Acquiring data at <loc>...
 
@@ -687,7 +689,16 @@ to produce something like:
 
     ### Acquiring data at "demo.pl", line 7...
 
-You can, of course, use both in the same comment as well.
+You can also request just the filename (C<< <file> >>) or just the line
+number (C<< <line> >>) to get finer control over formatting:
+
+    ### Acquiring data at <file>[<line>]...
+
+and produce something like:
+
+    ### Acquiring data at demo.pl[7]...
+
+You can, of course, use any combination of stamps in the one comment.
 
 =back
 
@@ -838,7 +849,7 @@ example:
 
     for (@candidates) {       ### Evaluating |===[%]    |
 
-would be aninated like so:
+would be animated like so:
 
     Evaluating |[0%]                       |
 
